@@ -1,21 +1,20 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2009 The RapidSvn Group.  All rights reserved.
  *
- * This program is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
- * along with this program (in the file GPL.txt); if not, write to 
- * the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, 
- * Boston, MA  02110-1301  USA
+ * along with this program (in the file GPL.txt.  
+ * If not, see <http://www.gnu.org/licenses/>.
  *
  * This software consists of voluntary contributions made by many
  * individuals.  For exact contribution history, see the revision
@@ -58,47 +57,47 @@ public:
   /**
    * default constructor
    */
-  FolderItemData ();
+  FolderItemData();
 
   /**
    * copy constructor
    */
-  FolderItemData (const FolderItemData& src);
+  FolderItemData(const FolderItemData& src);
 
   /**
    * destructor
    */
-  virtual ~FolderItemData ();
+  virtual ~FolderItemData();
 
   /**
    * initialize the member variables
    */
   void
-  Create (const int folderType,
-          const wxString & path = wxEmptyString,
-          const wxString & name = wxEmptyString,
-          bool hasChildren = false);
+  Create(const int folderType,
+         const wxString & path = wxEmptyString,
+         const wxString & name = wxEmptyString,
+         bool hasChildren = false);
 
   const int
-  getFolderType () const
+  getFolderType() const
   {
     return m_folderType;
   }
 
   const wxString&
-  getPath () const
+  getPath() const
   {
     return m_path;
   }
 
   const wxString&
-  getName () const
+  getName() const
   {
     return m_name;
   }
 
   const bool
-  hasChildren () const
+  hasChildren() const
   {
     return m_hasChildren;
   }
@@ -110,7 +109,7 @@ public:
    * @retval true existing folder
    * @retval false unreal/virtual entry
    */
-  const bool isReal () const
+  const bool isReal() const
   {
     switch (m_folderType)
     {
@@ -124,13 +123,13 @@ public:
   }
 
   const svn::Status &
-  getStatus () const
+  getStatus() const
   {
     return m_status;
   }
 
   void
-  setStatus (const svn::Status & status)
+  setStatus(const svn::Status & status)
   {
     m_status = status;
   }
