@@ -1,21 +1,20 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2009 The RapidSvn Group.  All rights reserved.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- * 
- * This library is distributed in the hope that it will be useful,
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- * 
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library (in the file LGPL.txt); if not, 
- * write to the Free Software Foundation, Inc., 51 Franklin St, 
- * Fifth Floor, Boston, MA  02110-1301  USA
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in the file GPL.txt.  
+ * If not, see <http://www.gnu.org/licenses/>.
  *
  * This software consists of voluntary contributions made by many
  * individuals.  For exact contribution history, see the revision
@@ -29,30 +28,32 @@
 // apr api
 #include "apr_file_io.h"
 
-// svncpp 
+// svncpp
 #include "svncpp/path.hpp"
 #include "svncpp/pool.hpp"
 #include "svncpp/url.hpp"
 
 namespace svn
 {
-  Path::Path (const char * path)
+  const PathVector EmptyPathVector;
+
+  Path::Path(const char * path)
   {
-    init (path);
+    init(path);
   }
 
-  Path::Path (const std::string & path) 
+  Path::Path(const std::string & path)
   {
-    init (path.c_str ());
+    init(path.c_str());
   }
 
-  Path::Path (const Path & path) 
+  Path::Path(const Path & path)
   {
-    init (path.c_str ());
+    init(path.c_str());
   }
 
   void
-  Path::init (const char * path)
+  Path::init(const char * path)
   {
     Pool pool;
 
@@ -62,38 +63,35 @@ namespace svn
       m_path = "";
     else
     {
-      const char * int_path = 
-        svn_path_internal_style (path, pool.pool () );
-    
+      const char * int_path =
+        svn_path_internal_style(path, pool.pool());
+
       m_path = int_path;
-      
-      if (svn::Url::isValid (int_path))
-      {
+
+      if (svn::Url::isValid(int_path))
         m_pathIsUrl = true;
-        m_path = svn::Url::escape (int_path);
-      }
     }
   }
 
   const std::string &
-  Path::path () const
+  Path::path() const
   {
     return m_path;
   }
 
-  const char * 
+  const char *
   Path::c_str() const
   {
-    return m_path.c_str ();
+    return m_path.c_str();
   }
 
-  Path& 
+  Path&
   Path::operator= (const Path & path)
   {
     if (this == &path)
       return *this;
 
-    init (path.c_str ());
+    init(path.c_str());
 
     return *this;
   }
@@ -101,33 +99,33 @@ namespace svn
   bool
   Path::operator== (const Path& path) const
   {
-    if (path.path () == this->path ())
+    if (path.path() == this->path())
       return true;
 
     return false;
   }
 
   bool
-  Path::isset () const
+  Path::isset() const
   {
-    return m_path.length () > 0;
+    return m_path.length() > 0;
   }
 
   const bool
-  Path::isUrl () const
+  Path::isUrl() const
   {
     return m_pathIsUrl;
   }
 
-  static bool 
-  isAbsolute (const char * path)
+  static bool
+  isAbsolute(const char * path)
   {
     if (0 == path)
       return false;
 
-    std::string p (path);
+    std::string p(path);
 
-    if (0 == p.length ())
+    if (0 == p.length())
       return false;
 
     // a path that begins with "/" is absolute
@@ -136,7 +134,7 @@ namespace svn
 
     // a path with a ":" like "http://xxx" or
     // "c:/foo" is absolute too
-    if (p.find (":", 0) != std::string::npos)
+    if (p.find(":", 0) != std::string::npos)
       return true;
 
     // Well it's relative
@@ -144,7 +142,7 @@ namespace svn
   }
 
   void
-  Path::addComponent (const char * component)
+  Path::addComponent(const char * component)
   {
     Pool pool;
 
@@ -157,62 +155,62 @@ namespace svn
 
     // if the @a component is absolute, simply
     // use it
-    if (isAbsolute (component))
+    if (isAbsolute(component))
     {
       m_path = component;
       return;
     }
 
-    if (Url::isValid (m_path.c_str ()))
+    if (Url::isValid(m_path.c_str()))
     {
       const char * newPath =
-        svn_path_url_add_component (m_path.c_str (),
-                                    component,
-                                    pool);
+        svn_path_url_add_component(m_path.c_str(),
+                                   component,
+                                   pool);
       m_path = newPath;
     }
     else
     {
-      svn_stringbuf_t * pathStringbuf = 
-        svn_stringbuf_create (m_path.c_str (), pool);
+      svn_stringbuf_t * pathStringbuf =
+        svn_stringbuf_create(m_path.c_str(), pool);
 
-      svn_path_add_component (pathStringbuf,
-                              component);
+      svn_path_add_component(pathStringbuf,
+                             component);
 
       m_path = pathStringbuf->data;
     }
   }
 
-  void 
-  Path::addComponent (const std::string & component)
+  void
+  Path::addComponent(const std::string & component)
   {
-    addComponent (component.c_str ());
+    addComponent(component.c_str());
   }
 
   void
-  Path::split (std::string & dirpath, std::string & basename) const
+  Path::split(std::string & dirpath, std::string & basename) const
   {
     Pool pool;
 
     const char * cdirpath;
     const char * cbasename;
 
-    svn_path_split (m_path.c_str (), &cdirpath, &cbasename, pool);
+    svn_path_split(m_path.c_str(), &cdirpath, &cbasename, pool);
 
     dirpath = cdirpath;
     basename = cbasename;
   }
 
   void
-  Path::split (std::string & dir, std::string & filename, std::string & ext) const
+  Path::split(std::string & dir, std::string & filename, std::string & ext) const
   {
     std::string basename;
 
     // first split path into dir and filename+ext
-    split (dir, basename);
+    split(dir, basename);
 
     // next search for last .
-    size_t pos = basename.find_last_of (".");
+    size_t pos = basename.find_last_of(".");
     if (pos == std::string::npos)
     {
       filename = basename;
@@ -220,48 +218,49 @@ namespace svn
     }
     else
     {
-      filename = basename.substr (0, pos);
-      ext = basename.substr (pos);
+      filename = basename.substr(0, pos);
+      ext = basename.substr(pos);
     }
   }
 
   std::string
-  Path::basename () const
+  Path::basename() const
   {
     std::string dir;
     std::string filename;
 
-    split (dir, filename);
+    split(dir, filename);
 
     return filename;
   }
 
   std::string
-  Path::dirpath () const
+  Path::dirpath() const
   {
     std::string dir;
     std::string filename;
 
-    split (dir, filename);
+    split(dir, filename);
 
     return dir;
   }
 
   std::string
-  Path::substr (const size_t count) const
+  Path::substr(const size_t count) const
   {
-    if (m_path.length () > count)
-      return m_path.substr (count);
+    if (m_path.length() > count)
+      return m_path.substr(count);
     else
       return "";
   }
 
   std::string
-  Path::unescape () const
+  Path::unescape() const
   {
-    return svn::Url::unescape (m_path.c_str ());
+    return svn::Url::unescape(m_path.c_str());
   }
 
+
   /* ===================================================================
    * The next two Fixed_* functions are copies of the APR
    * apr_temp_dir_get functionality with a fix applied.
@@ -274,26 +273,26 @@ namespace svn
 
 #define test_tempdir    Fixed_test_tempdir
 #define apr_temp_dir_get    Fixed_apr_temp_dir_get
-  
+
   static char global_temp_dir[APR_PATH_MAX+1] = { 0 };
-  
+
   /* Try to open a temporary file in the temporary dir, write to it,
     and then close it. */
   static int Fixed_test_tempdir(const char *temp_dir, apr_pool_t *p)
   {
-      apr_file_t *dummy_file;
-      // This is the only actual fix - adding the ".XXXXXX"!
-      const char *path = apr_pstrcat(p, temp_dir, "/apr-tmp.XXXXXX", NULL);
-  
-      if (apr_file_mktemp(&dummy_file, (char *)path, 0, p) == APR_SUCCESS) {
-          if (apr_file_putc('!', dummy_file) == APR_SUCCESS) {
-              if (apr_file_close(dummy_file) == APR_SUCCESS) {
-                  apr_file_remove(path, p);
-                  return 1;
-              }
-          }
+    apr_file_t *dummy_file;
+    // This is the only actual fix - adding the ".XXXXXX"!
+    const char *path = apr_pstrcat(p, temp_dir, "/apr-tmp.XXXXXX", NULL);
+
+    if (apr_file_mktemp(&dummy_file, (char *)path, 0, p) == APR_SUCCESS) {
+      if (apr_file_putc('!', dummy_file) == APR_SUCCESS) {
+        if (apr_file_close(dummy_file) == APR_SUCCESS) {
+          apr_file_remove(path, p);
+          return 1;
+        }
       }
-      return 0;
+    }
+    return 0;
   }
 
   static apr_status_t Fixed_apr_temp_dir_get(const char **temp_dir, apr_pool_t *p)
@@ -315,58 +314,58 @@ namespace svn
           "/tmp"
           "/var/tmp"
           "/usr/tmp"
-          `pwd` 
+          `pwd`
 
        NOTE: This algorithm is basically the same one used by Python
        2.2's tempfile.py module.  */
 
     /* Try the environment first. */
     for (i = 0; i < (sizeof(try_envs) / sizeof(const char *)); i++) {
-        char *value;
-        apr_err = apr_env_get(&value, try_envs[i], p);
-        if ((apr_err == APR_SUCCESS) && value) {
-            apr_size_t len = strlen(value);
-            if (len && (len < APR_PATH_MAX) && test_tempdir(value, p)) {
-                memcpy(global_temp_dir, value, len + 1);
-                goto end;
-            }
+      char *value;
+      apr_err = apr_env_get(&value, try_envs[i], p);
+      if ((apr_err == APR_SUCCESS) && value) {
+        apr_size_t len = strlen(value);
+        if (len && (len < APR_PATH_MAX) && test_tempdir(value, p)) {
+          memcpy(global_temp_dir, value, len + 1);
+          goto end;
         }
+      }
     }
 
     /* Next, try a set of hard-coded paths. */
     for (i = 0; i < (sizeof(try_dirs) / sizeof(const char *)); i++) {
-        if (test_tempdir(try_dirs[i], p)) {
-            memcpy(global_temp_dir, try_dirs[i], strlen(try_dirs[i]) + 1);
-            goto end;
-        }
+      if (test_tempdir(try_dirs[i], p)) {
+        memcpy(global_temp_dir, try_dirs[i], strlen(try_dirs[i]) + 1);
+        goto end;
+      }
     }
 
     /* Finally, try the current working directory. */
     if (APR_SUCCESS == apr_filepath_get(&cwd, APR_FILEPATH_NATIVE, p)) {
-        if (test_tempdir(cwd, p)) {
-            memcpy(global_temp_dir, cwd, strlen(cwd) + 1);
-            goto end;
-        }
+      if (test_tempdir(cwd, p)) {
+        memcpy(global_temp_dir, cwd, strlen(cwd) + 1);
+        goto end;
+      }
     }
 
 end:
     if (global_temp_dir[0]) {
-        *temp_dir = apr_pstrdup(p, global_temp_dir);
-        return APR_SUCCESS;
+      *temp_dir = apr_pstrdup(p, global_temp_dir);
+      return APR_SUCCESS;
     }
     return APR_EGENERAL;
   }
   /* ===================================================================
    * End of inserted fixed APR code
    */
-   
+
   Path
-  Path::getTempDir ()
+  Path::getTempDir()
   {
     const char * tempdir = NULL;
     Pool pool;
 
-    if (apr_temp_dir_get (&tempdir, pool) != APR_SUCCESS)
+    if (apr_temp_dir_get(&tempdir, pool) != APR_SUCCESS)
     {
       tempdir = NULL;
     }
@@ -374,29 +373,28 @@ end:
     return tempdir;
   }
 
-  size_t 
-  Path::length () const
+  size_t
+  Path::length() const
   {
-    return m_path.length ();
+    return m_path.length();
   }
 
   std::string
-  Path::native () const
+  Path::native() const
   {
-    Pool pool;
-
     if (m_pathIsUrl)
     {
       // this converts something like
-      // http://foo/my%20location 
-      // to 
+      // http://foo/my%20location
+      // to
       // http://foo/my location
-      return svn_path_uri_decode (m_path.c_str (), pool); 
+	    return Url::unescape(m_path.c_str());
     }
     else
     {
       // On Windows, p://foo/bar will be converted to p:\foo\bar
-      return svn_path_local_style (m_path.c_str (), pool);
+	    Pool pool;
+      return svn_path_local_style(m_path.c_str(), pool);
     }
   }
 }
