@@ -1,21 +1,20 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2009 The RapidSvn Group.  All rights reserved.
  *
- * This program is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
- * along with this program (in the file GPL.txt); if not, write to 
- * the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, 
- * Boston, MA  02110-1301  USA
+ * along with this program (in the file GPL.txt.  
+ * If not, see <http://www.gnu.org/licenses/>.
  *
  * This software consists of voluntary contributions made by many
  * individuals.  For exact contribution history, see the revision
@@ -27,7 +26,7 @@
 
 #define APPLICATION_NAME wxT("RapidSVN")
 
-#define RAPIDSVN_COPYRIGHT "(C) 2002-2008 The RapidSvn Group. All rights reserved."
+#define RAPIDSVN_COPYRIGHT "(c) 2002-2009 The RapidSvn Group. All rights reserved."
 
 /* Symbols that define the version number.
  * The numbers are maintained in the file version.xml (in the
@@ -43,15 +42,15 @@
  */
 #define RAPIDSVN_VER_MAJOR 0
 
-/** 
+/**
  * Minor version number.
  */
-#define RAPIDSVN_VER_MINOR 9
+#define RAPIDSVN_VER_MINOR 10
 
-/** 
- * Micro version number. 
+/**
+ * Micro version number.
  */
-#define RAPIDSVN_VER_MICRO 6
+#define RAPIDSVN_VER_MICRO 0
 
 /**
  * Patch string. Can be empty
@@ -61,11 +60,11 @@
 /**
  * Combined version string
  */
-#define RAPIDSVN_VER_STR "0.9.6"
+#define RAPIDSVN_VER_STR "0.10.0"
 
 /* Symbolic name of the milestone
    Modify whenever Minor number is changed. */
-#define RAPIDSVN_VER_MILESTONE "0.9.6"
+#define RAPIDSVN_VER_MILESTONE "0.10"
 
 #endif
 /* -----------------------------------------------------------------
